Colour

Struct Colour 

pub struct Colour {
    pub r: u8,
    pub g: u8,
    pub b: u8,
}
A struct to store colour values. Can be created from RGB, HSV or greyscale values, but is ultimately stored as RGB.

Fields

r: u8

The red channel of the colour

g: u8

The green channel of the colour

b: u8

The blue channel of the colour

Implementations

Source

impl Colour

pub const BLACK: Self

A white Colour of RGB (0,0,0)

pub const WHITE: Self

A white Colour of RGB (255,255,255)

pub const fn rgb(r: u8, g: u8, b: u8) -> Self

Create a Colour from an RGB value

pub fn hsv(hue: u8, sat: u8, val: u8) -> Self

Create a Colour from an HSV value

pub const fn greyscale(v: u8) -> Self

Create a Colour from a single brightness value, resulting in a shade of grey