Canvas

Trait Canvas 

pub trait Canvas: Sized {
    // Required method
    fn plot(&mut self, pos: Vec2D, c: ColChar);
}
A struct that can be drawn to by elements which implement CanDraw

The only structs that implement this in gemini are View and ScaleFitView.

Required Methods

fn plot(&mut self, pos: Vec2D, c: ColChar)

Plot a ColChar to the Canvas at pos

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors