This module holds every struct designed to contain various ViewElements. Since every container is itself a ViewElement, containers can be combined by nesting inside of each other.

Structs

  • Contains references to all added objects. Meant to be used specifically for collision calculations
  • A PixelContainer only has a pixels property, which gets returned directly to the View during blit
  • VisibilityToggle is a container for a ViewElement with a property visible. When blit to the view the contained element will only appear if visible is true