Struct gemini_engine::elements::containers::CollisionContainer
source · pub struct CollisionContainer<'a> {
pub elements: Vec<&'a dyn ViewElement>,
}Expand description
Contains references to all added objects. Meant to be used specifically for collision calculations
Fields
elements: Vec<&'a dyn ViewElement>Implementations
sourceimpl<'a> CollisionContainer<'a>
impl<'a> CollisionContainer<'a>
sourcepub const fn new() -> CollisionContainer<'a>
pub const fn new() -> CollisionContainer<'a>
Create a new CollisionLayer
sourcepub fn push(&mut self, element: &'a impl ViewElement)
pub fn push(&mut self, element: &'a impl ViewElement)
Add an element to the container
pub fn generate_collision_points(&self) -> Vec<Vec2D>
sourcepub fn contains(&self, pos: Vec2D) -> bool
pub fn contains(&self, pos: Vec2D) -> bool
Returns true if there is an element from the CollisionContainer at the given coordinates
sourcepub fn overlaps_element(&self, element: &impl ViewElement) -> bool
pub fn overlaps_element(&self, element: &impl ViewElement) -> bool
Returns true if the given ViewElement is overlapping the CollisionContainer
sourcepub fn will_overlap_element(
&self,
element: &impl ViewElement,
offset: Vec2D
) -> bool
pub fn will_overlap_element( &self, element: &impl ViewElement, offset: Vec2D ) -> bool
Returns true if the element will be overlapping the CollisionContainer when the offset is applied