Struct gemini_engine::elements::containers::PixelContainer
source · pub struct PixelContainer {
pub pixels: Vec<Point>,
}Expand description
A PixelContainer only has a pixels property, which gets returned directly to the View during blit
Fields
pixels: Vec<Point>This is the value that gets returned by active_pixels()
Implementations
sourceimpl PixelContainer
impl PixelContainer
sourcepub fn append(&mut self, pixels: &mut Vec<Point>)
pub fn append(&mut self, pixels: &mut Vec<Point>)
Moves all the pixels into the PixelContainer, leaving the input empty.
sourcepub fn append_points(&mut self, points: Vec<Vec2D>, fill_char: ColChar)
pub fn append_points(&mut self, points: Vec<Vec2D>, fill_char: ColChar)
Append vector of coordinates and a single ColChar for all of them.
sourcepub fn blit<E: ViewElement>(&mut self, element: &E)
pub fn blit<E: ViewElement>(&mut self, element: &E)
Blit a ViewElement to the PixelContainer.