A module containing various helper functions and structs

Enums

  • Wrapping is used to determine how you want to handle out-of-bounds pixels during plotting pixels to the screen. Here’s how each possible value functions:

Functions

  • Draw a pseudo-line between the independent and dependent positions. Used by Triangle
  • Returns true if the Vec2Ds in the vector are arranged clockwise
  • Extract the positions from a vector of Points
  • Combine a vector of Vec2Ds and a single fill_char into a vector of (Vec2D, char) tuples, ready to return for ViewElement::active_pixels. Useful if your ViewElement only has one fill character across all of it