pub struct Grid3D {
    pub transform: Transform3D,
    pub cell_size: f64,
    pub cell_count: usize,
    pub fill_char: ColChar,
    /* private fields */
}
A flat grid to display where the ground is

Fields

transform: Transform3Dcell_size: f64

The length of each cell’s width and depth

cell_count: usize

The number of cells alon each side. The total number of cells will be cell_count^2

fill_char: ColChar

Implementations

source

impl Grid3D

source

pub fn new(cell_size: f64, cell_count: usize, fill_char: ColChar) -> Grid3D

Create a new grid with the specified cell size and count

source

pub fn reload(&mut self)

Regenerate the grid. Call this if you at any point change the cell_size or cell_count fields