pub enum DisplayMode {
Debug,
Points {
fill_char: ColChar,
},
Wireframe {
backface_culling: bool,
},
Solid,
Illuminated {
lights: Vec<Light>,
},
}Expand description
DisplayMode determines how the Viewport renders our 3D objects. This is the Gemini equivalent of Blender’s Viewport Shading options
Variants
Debug
DisplayMode::Debug does the same thing, but shows the vertices as the indices that represent them (this is useful when you are constructing a mesh)
Points
DisplayMode::Points only renders the object’s vertices as single pixels with the ColChar chosen with the fill_char enum parameter
Wireframe
DisplayMode::Wireframe renders the edges of the meshes, without filling in the shapes. You can choose whether you want to render with backface culling using the backface_culling enum parameter
Fields
Solid
DisplayMode::Solid renders the full faces of all the meshes. This is normally the final render
Illuminated
DisplayMode::Illuminated will replace your faces’ text_chars with a character of different size to emulate light, based on a given list of Lights