Module gemini_engine::elements::containers
source · Expand description
This module holds every struct designed to contain various ViewElements. Since every container is itself a ViewElement, containers can be combined by nesting inside of each other.
Structs
- Contains references to all added objects. Meant to be used specifically for collision calculations
- A
PixelContaineronly has apixelsproperty, which gets returned directly to the View during blit VisibilityToggleis a container for aViewElementwith a propertyvisible. When blit to the view the contained element will only appear ifvisibleistrue